EXPORTS
	??1CRepository@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CRepository::~CRepository(void)
	?Create@CRepository@@QAEHKABN@Z @ 2 NONAME ; public: int __thiscall CRepository::Create(unsigned long,double const &)
	?Create@CRepository@@QAEHKABVTDesC16@@@Z @ 3 NONAME ; public: int __thiscall CRepository::Create(unsigned long,class TDesC16 const &)
	?Create@CRepository@@QAEHKABVTDesC8@@@Z @ 4 NONAME ; public: int __thiscall CRepository::Create(unsigned long,class TDesC8 const &)
	?Create@CRepository@@QAEHKH@Z @ 5 NONAME ; public: int __thiscall CRepository::Create(unsigned long,int)
	?Delete@CRepository@@QAEHK@Z @ 6 NONAME ; public: int __thiscall CRepository::Delete(unsigned long)
	?FindEqL@CRepository@@QAEHKKABNAAV?$RArray@K@@@Z @ 7 NONAME ; public: int __thiscall CRepository::FindEqL(unsigned long,unsigned long,double const &,class RArray<unsigned long> &)
	?FindEqL@CRepository@@QAEHKKABVTDesC16@@AAV?$RArray@K@@@Z @ 8 NONAME ; public: int __thiscall CRepository::FindEqL(unsigned long,unsigned long,class TDesC16 const &,class RArray<unsigned long> &)
	?FindEqL@CRepository@@QAEHKKABVTDesC8@@AAV?$RArray@K@@@Z @ 9 NONAME ; public: int __thiscall CRepository::FindEqL(unsigned long,unsigned long,class TDesC8 const &,class RArray<unsigned long> &)
	?FindEqL@CRepository@@QAEHKKHAAV?$RArray@K@@@Z @ 10 NONAME ; public: int __thiscall CRepository::FindEqL(unsigned long,unsigned long,int,class RArray<unsigned long> &)
	?FindL@CRepository@@QAEHKKAAV?$RArray@K@@@Z @ 11 NONAME ; public: int __thiscall CRepository::FindL(unsigned long,unsigned long,class RArray<unsigned long> &)
	?FindNeqL@CRepository@@QAEHKKABNAAV?$RArray@K@@@Z @ 12 NONAME ; public: int __thiscall CRepository::FindNeqL(unsigned long,unsigned long,double const &,class RArray<unsigned long> &)
	?FindNeqL@CRepository@@QAEHKKABVTDesC16@@AAV?$RArray@K@@@Z @ 13 NONAME ; public: int __thiscall CRepository::FindNeqL(unsigned long,unsigned long,class TDesC16 const &,class RArray<unsigned long> &)
	?FindNeqL@CRepository@@QAEHKKABVTDesC8@@AAV?$RArray@K@@@Z @ 14 NONAME ; public: int __thiscall CRepository::FindNeqL(unsigned long,unsigned long,class TDesC8 const &,class RArray<unsigned long> &)
	?FindNeqL@CRepository@@QAEHKKHAAV?$RArray@K@@@Z @ 15 NONAME ; public: int __thiscall CRepository::FindNeqL(unsigned long,unsigned long,int,class RArray<unsigned long> &)
	?Get@CRepository@@QAEHKAAH@Z @ 16 NONAME ; public: int __thiscall CRepository::Get(unsigned long,int &)
	?Get@CRepository@@QAEHKAAN@Z @ 17 NONAME ; public: int __thiscall CRepository::Get(unsigned long,double &)
	?Get@CRepository@@QAEHKAAVTDes16@@@Z @ 18 NONAME ; public: int __thiscall CRepository::Get(unsigned long,class TDes16 &)
	?Get@CRepository@@QAEHKAAVTDes8@@@Z @ 19 NONAME ; public: int __thiscall CRepository::Get(unsigned long,class TDes8 &)
	?NewL@CRepository@@SAPAV1@VTUid@@@Z @ 20 NONAME ; public: static class CRepository * __cdecl CRepository::NewL(class TUid)
	?NewLC@CRepository@@SAPAV1@VTUid@@@Z @ 21 NONAME ; public: static class CRepository * __cdecl CRepository::NewLC(class TUid)
	?NotifyCancel@CRepository@@QAEHK@Z @ 22 NONAME ; public: int __thiscall CRepository::NotifyCancel(unsigned long)
	?NotifyCancel@CRepository@@QAEHKK@Z @ 23 NONAME ; public: int __thiscall CRepository::NotifyCancel(unsigned long,unsigned long)
	?NotifyCancelAll@CRepository@@QAEHXZ @ 24 NONAME ; public: int __thiscall CRepository::NotifyCancelAll(void)
	?NotifyRequest@CRepository@@QAEHKAAVTRequestStatus@@@Z @ 25 NONAME ; public: int __thiscall CRepository::NotifyRequest(unsigned long,class TRequestStatus &)
	?NotifyRequest@CRepository@@QAEHKKAAVTRequestStatus@@@Z @ 26 NONAME ; public: int __thiscall CRepository::NotifyRequest(unsigned long,unsigned long,class TRequestStatus &)
	?Reset@CRepository@@QAEHK@Z @ 27 NONAME ; public: int __thiscall CRepository::Reset(unsigned long)
	?Reset@CRepository@@QAEHXZ @ 28 NONAME ; public: int __thiscall CRepository::Reset(void)
	?Set@CRepository@@QAEHKABN@Z @ 29 NONAME ; public: int __thiscall CRepository::Set(unsigned long,double const &)
	?Set@CRepository@@QAEHKABVTDesC16@@@Z @ 30 NONAME ; public: int __thiscall CRepository::Set(unsigned long,class TDesC16 const &)
	?Set@CRepository@@QAEHKABVTDesC8@@@Z @ 31 NONAME ; public: int __thiscall CRepository::Set(unsigned long,class TDesC8 const &)
	?Set@CRepository@@QAEHKH@Z @ 32 NONAME ; public: int __thiscall CRepository::Set(unsigned long,int)
	?CommitTransaction@CRepository@@QAEHAAK@Z @ 33 NONAME ; int CRepository::CommitTransaction(unsigned long &))
	?StartTransaction@CRepository@@QAEHW4TTransactionMode@1@@Z @ 34 NONAME ; int CRepository::StartTransaction(enum CRepository::TTransactionMode)
	?CancelTransaction@CRepository@@QAEXXZ @ 35 NONAME ; void CRepository::CancelTransaction(void)
	?CreateSemaphore@CRepository@@QAEHK@Z @ 36 NONAME ABSENT
	?Move@CRepository@@QAEHKKKAAK@Z @ 37 NONAME ; int CRepository::Move(unsigned long, unsigned long, unsigned long, unsigned long &)
	?CleanupCancelTransactionPushL@CRepository@@QAEXXZ @ 38 NONAME ; void CRepository::CleanupCancelTransactionPushL(void)
	?TransactionState@CRepository@@QAEHXZ @ 39 NONAME ABSENT
	?CleanupFailTransactionPushL@CRepository@@QAEXXZ @ 40 NONAME ; void CRepository::CleanupFailTransactionPushL(void)
	?FailTransaction@CRepository@@QAEXXZ @ 41 NONAME ; void CRepository::FailTransaction(void)
	?CommitTransaction@CRepository@@QAEXAAVTDes8@@AAVTRequestStatus@@@Z @ 42 NONAME ; void CRepository::CommitTransaction(class TDes8 &, class TRequestStatus &)
	?StartTransaction@CRepository@@QAEXW4TTransactionMode@1@AAVTRequestStatus@@@Z @ 43 NONAME ; void CRepository::StartTransaction(enum CRepository::TTransactionMode, class TRequestStatus &)
	?Delete@CRepository@@QAEHKKAAK@Z @ 44 NONAME ; int CRepository::Delete(unsigned long, unsigned long, unsigned long &)
	?Get@CRepository@@QAEHKAAVTDes8@@AAH@Z @ 45 NONAME ; int CRepository::Get(unsigned long, class TDes8 &, int &)
	?Get@CRepository@@QAEHKAAVTDes16@@AAH@Z @ 46 NONAME ; int CRepository::Get(unsigned long, class TDes16 &, int &)
	?SetGetParameters@CRepository@@SAHABVTIpcArgs@@@Z @ 47 NONAME ABSENT
	?GetMeta@CRepository@@QAEHKAAK@Z @ 48 NONAME ; int CRepository::GetMeta(unsigned long, unsigned long &)

